#
# Copyright 2001, 2002 (C) Metacosm development team
#

#SGMLTOOLS v1
SGML2TXT_V1=sgml2txt
SGML2HTML_V1=sgml2html
SGML2PS_V1=sgml2latex

#Options SGMLTOOLS v1
TEXTOPT_V1=$(OPT_V1) -f
HTMLOPT_V1=$(OPT_V1)
PSOPT_V1=$(OPT_V1) --output=ps

#SGMLTOOLS v2
SGML2TXT_V2=sgmltools
SGML2HTML_V2=sgmltools
SGML2PS_V2=sgmltools

#Options SGMLTOOLS v2
TEXTOPT_V2=$(OPT_V2) -b txt
HTMLOPT_V2=$(OPT_V2) -b html
PSOPT_V2=$(OPT_V2) -b ps

WEB_SGML_TOOL=vim
WEB_SGML_OPTIONS=-f +'set background=dark' +syn\ on +'so $$VIMRUNTIME/syntax/2html.vim' +wq +q

#Directories
TXT_DIR=txt
PS_DIR=ps
HTML_DIR=html
WEB_SGML_DIR=websgml
HTML_DIR_RFC=$(HTML_DIR)/$(patsubst %.sgml,%,$<)

#Paths
vpath %.txt $(TXT_DIR)
vpath %.ps.gz $(PS_DIR)
vpath %.sgml.html $(WEB_SGML_DIR)
vpath %.html $(HTML_DIR_RFC)

#Files in linuxdoc or metacosm-DTD
SGML_V1:=$(shell grep -ilE "<\!doctype (metacosm|linuxdoc)" *.sgml)
TXT_V1:= $(patsubst %.sgml,%.txt,$(SGML_V1))
PS_V1:= $(patsubst %.sgml,%.ps.gz,$(SGML_V1))
HTML_V1:= $(patsubst %.sgml,%.html,$(SGML_V1))

#Files in Docbook-DTD
SGML_V2:=$(shell grep -ilE "<\!doctype.*docbook" *.sgml)
TXT_V2:= $(patsubst %.sgml,%.txt,$(SGML_V2))
PS_V2:= $(patsubst %.sgml,%.ps.gz,$(SGML_V2))
HTML_V2:= $(patsubst %.sgml,%.html,$(SGML_V2))

WEB_SGML:= $(patsubst %.sgml,%.sgml.html,$(wildcard *.sgml))

all: txt ps html web_sgml

txt: $(TXT_V1) $(TXT_V2)

html: $(HTML_V1) $(HTML_V2)

ps: $(PS_V1) $(PS_V2)

web_sgml: $(WEB_SGML)

$(TXT_V1): %.txt: %.sgml
	@mkdir -p $(TXT_DIR)
	$(SGML2TXT_V1) $(TEXTOPT_V1) $<
	@mv $@ $(TXT_DIR)

$(TXT_V2): %.txt: %.sgml
	@mkdir -p $(TXT_DIR)
	$(SGML2TXT_V2) $(TEXTOPT_V2) $<
	@mv $@ $(TXT_DIR)

$(PS_V1): %.ps.gz: %.sgml
	@mkdir -p $(PS_DIR)
	$(SGML2PS_V1) $(PSOPT_V1) $(patsubst %.ps.gz,%.ps,$<)
	@gzip $(patsubst %.ps.gz,%.ps,$@)
	@mv $@ $(PS_DIR)

$(PS_V2): %.ps.gz: %.sgml
	@mkdir -p $(PS_DIR)
	$(SGML2PS_V2) $(PSOPT_V2) $(patsubst %.ps.gz,%.ps,$<)
	@gzip $(patsubst %.ps.gz,%.ps,$@)
	@mv $@ $(PS_DIR)

$(HTML_V1): %.html: %.sgml
	@mkdir -p $(HTML_DIR_RFC)
	$(SGML2HTML_V1) $(HTMLOPT_V1) $<
	@mv $(patsubst %.html,%*.html,$@) $(HTML_DIR_RFC)

$(HTML_V2): %.html: %.sgml
	@rm -rf $(HTML_DIR_RFC)
	$(SGML2HTML_V2) $(HTMLOPT_V2) $<
	@mv -f $(patsubst %.html,%,$@) $(HTML_DIR)

$(WEB_SGML): %.sgml.html: %.sgml
	@mkdir -p $(WEB_SGML_DIR)
	$(WEB_SGML_TOOL) $(WEB_SGML_OPTIONS) "$<"
	@mv $@ $(WEB_SGML_DIR)

dist: $(TXT) $(HTML) $(PS)
	tar czf $(DIST) *
